@@ -1,13 +1,13 @@
-// This is UFC (Unified Form-assembly Code) v. 2.2.0.
+// This is UFC (Unified Form-assembly Code) v. 2.3.0.
 // This code is released into the public domain.
 //
-// The FEniCS Project (http://www.fenicsproject.org/) 2006-2013.
+// The FEniCS Project (http://www.fenicsproject.org/) 2006-2014.
 
 #ifndef __UFC_H
 #define __UFC_H
 
 #define UFC_VERSION_MAJOR 2
-#define UFC_VERSION_MINOR 2
+#define UFC_VERSION_MINOR 3
 #define UFC_VERSION_MAINTENANCE 0
 
 #include <vector>
@@ -16,7 +16,7 @@
 
 #include <ufc_geometry.h>
 
-const char UFC_VERSION[] = "2.2.0";
+const char UFC_VERSION[] = "2.3.0";
 
 namespace ufc
 {
@@ -61,8 +61,7 @@ namespace ufc
     /// Constructor
     cell(): cell_shape(interval),
             topological_dimension(0), geometric_dimension(0),
-            entity_indices(0), coordinates(0), index(0), local_facet(-1),
-            mesh_identifier(-1) {}
+            index(0), local_facet(-1), mesh_identifier(-1) {}
 
     /// Destructor
     virtual ~cell() {}
@@ -77,13 +76,7 @@ namespace ufc
     std::size_t geometric_dimension;
 
     /// Array of global indices for the mesh entities of the cell
-    std::size_t** entity_indices;
-
-    /// Array of coordinates for the vertices of the cell
-    double** coordinates;
-
-    // FIXME: Temporary until we remove UFCCell
-    std::vector<double> vertex_coordinates;
+    std::vector<std::vector<std::size_t> > entity_indices;
 
     /// Cell index (short-cut for entity_indices[topological_dimension][0])
     std::size_t index;
@@ -230,7 +223,8 @@ namespace ufc
     /// Return a string identifying the dofmap
     virtual const char* signature() const = 0;
 
-    /// Return true iff mesh entities of topological dimension d are needed
+    /// Return true iff mesh entities of topological dimension d are
+    /// needed
     virtual bool needs_mesh_entities(std::size_t d) const = 0;
 
     /// Return the topological dimension of the associated cell shape
@@ -243,16 +237,15 @@ namespace ufc
     virtual std::size_t global_dimension(const std::vector<std::size_t>&
                                          num_global_mesh_entities) const = 0;
 
-    /// Return the dimension of the local finite element function space for a cell
-    virtual std::size_t local_dimension(const cell& c) const = 0;
-
-    /// Return the maximum dimension of the local finite element function space
-    virtual std::size_t max_local_dimension() const = 0;
+    /// Return the dimension of the local finite element function space
+    /// for a cell
+    virtual std::size_t local_dimension() const = 0;
 
     /// Return the number of dofs on each cell facet
     virtual std::size_t num_facet_dofs() const = 0;
 
-    /// Return the number of dofs associated with each cell entity of dimension d
+    /// Return the number of dofs associated with each cell entity of
+    /// dimension d
     virtual std::size_t num_entity_dofs(std::size_t d) const = 0;
 
     /// Tabulate the local-to-global mapping of dofs on a cell
